using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using WCS.Model;
using WCS.Model.ApiModel.MatInventoryDetail;
using WCS.Model.ApiModel.OutStore;

namespace WCS.BLL.Services.IService
{
    public interface IOutstoreService
    {
        public Task<ResponseCommon<List<MatInventorySummaryModel>>> importMat(List<OutImportMatModel> list);
        public Task<ResponseBase> SysOutOrderByMatCode(SysOutOrderByMatCodeRequest request);

        public Task<ResponseBase> SysOutOrderByMatSn(SysOutOrderByMatSnRequest request);

        public Task<ResponseBase> GetOutOrderList(GetOutOrderListRequest request);

        public Task<ResponseBase> GetOutOrderListByStatus(GetOutOrderListByStatusRequest request);

        public Task<ResponseBase> GetOutOrderDetail(GetOutOrderDetailRequest request);
        public Task<ResponseBase> GetOutOrderDetailSingleLight(GetOutOrderDetailRequest request);

        public Task<ResponseBase> GetOutOrderMatDetail(GetOutOrderDetailRequest request);

        public Task<ResponseBase> GoInOutstore(GetOutOrderDetailRequest request);

        public Task<ResponseBase> GoOutOutstore(GetOutOrderDetailRequest request);


        public Task<ResponseBase> SingleLightConfirmOutstore(OutOrderMatDetailModelSingle request);

    }
}
